# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodeUpdateRequest(Model):
    """InstallNodeUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param status_id: Required. The Installation status identifier of the
     nodes at time of install.
    :type status_id: int
    :param status_note: Installations notes typically used when a node is
     unable to be installed.
    :type status_note: str
    """

    _validation = {
        'status_id': {'required': True},
        'status_note': {'max_length': 200, 'min_length': 0},
    }

    _attribute_map = {
        'status_id': {'key': 'StatusId', 'type': 'int'},
        'status_note': {'key': 'StatusNote', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstallNodeUpdateRequest, self).__init__(**kwargs)
        self.status_id = kwargs.get('status_id', None)
        self.status_note = kwargs.get('status_note', None)
