# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .smart_diagnostics_api import SmartDiagnosticsApi
from .version import VERSION

__all__ = ['SmartDiagnosticsApi']

__version__ = VERSION

