# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetSizeChild(Model):
    """AssetSizeChild.

    All required parameters must be populated in order to send to Azure.

    :param size_id: Required.
    :type size_id: int
    :param size_name: Required.
    :type size_name: str
    :param size_code: Required.
    :type size_code: str
    """

    _validation = {
        'size_id': {'required': True},
        'size_name': {'required': True},
        'size_code': {'required': True},
    }

    _attribute_map = {
        'size_id': {'key': 'SizeId', 'type': 'int'},
        'size_name': {'key': 'SizeName', 'type': 'str'},
        'size_code': {'key': 'SizeCode', 'type': 'str'},
    }

    def __init__(self, *, size_id: int, size_name: str, size_code: str, **kwargs) -> None:
        super(AssetSizeChild, self).__init__(**kwargs)
        self.size_id = size_id
        self.size_name = size_name
        self.size_code = size_code
