# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PersonalAccessTokenCreateResponse(Model):
    """PersonalAccessTokenCreateResponse.

    :param id:
    :type id: str
    :param description:
    :type description: str
    :param token:
    :type token: str
    :param note:
    :type note: str
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'token': {'key': 'Token', 'type': 'str'},
        'note': {'key': 'Note', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PersonalAccessTokenCreateResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.description = kwargs.get('description', None)
        self.token = kwargs.get('token', None)
        self.note = kwargs.get('note', None)
