# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationCreateRequest(Model):
    """LocationCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param corporation_id: Required.
    :type corporation_id: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'abbreviation': {'max_length': 5},
        'corporation_id': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(LocationCreateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.corporation_id = kwargs.get('corporation_id', None)
