# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseStationChild(Model):
    """BaseStationChild.

    All required parameters must be populated in order to send to Azure.

    :param base_station_id: Required.
    :type base_station_id: long
    :param base_station_nickname:
    :type base_station_nickname: str
    :param base_station_serial_number:
    :type base_station_serial_number: str
    """

    _validation = {
        'base_station_id': {'required': True},
    }

    _attribute_map = {
        'base_station_id': {'key': 'BaseStationId', 'type': 'long'},
        'base_station_nickname': {'key': 'BaseStationNickname', 'type': 'str'},
        'base_station_serial_number': {'key': 'BaseStationSerialNumber', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BaseStationChild, self).__init__(**kwargs)
        self.base_station_id = kwargs.get('base_station_id', None)
        self.base_station_nickname = kwargs.get('base_station_nickname', None)
        self.base_station_serial_number = kwargs.get('base_station_serial_number', None)
