# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingValues(Model):
    """NodeSettingValues.

    :param current_value:
    :type current_value: str
    :param pending_value:
    :type pending_value: str
    """

    _attribute_map = {
        'current_value': {'key': 'CurrentValue', 'type': 'str'},
        'pending_value': {'key': 'PendingValue', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(NodeSettingValues, self).__init__(**kwargs)
        self.current_value = kwargs.get('current_value', None)
        self.pending_value = kwargs.get('pending_value', None)
