# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAnalyticsModelAddRequest(Model):
    """GroupAnalyticsModelAddRequest.

    All required parameters must be populated in order to send to Azure.

    :param model_id: Required.
    :type model_id: int
    :param properties:
    :type properties: list[~smartdiagnostics_sdk.models.SetPropertyChild]
    """

    _validation = {
        'model_id': {'required': True},
    }

    _attribute_map = {
        'model_id': {'key': 'ModelId', 'type': 'int'},
        'properties': {'key': 'Properties', 'type': '[SetPropertyChild]'},
    }

    def __init__(self, **kwargs):
        super(GroupAnalyticsModelAddRequest, self).__init__(**kwargs)
        self.model_id = kwargs.get('model_id', None)
        self.properties = kwargs.get('properties', None)
