# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetRunningSpeedChild(Model):
    """AssetRunningSpeedChild.

    :param running_speed_min:
    :type running_speed_min: float
    :param running_speed_max:
    :type running_speed_max: float
    :param running_speed_type:
    :type running_speed_type: str
    :param running_speed_reference_monitoring_point_id:
    :type running_speed_reference_monitoring_point_id: str
    :param running_speed_sensor_role_type: Possible values include: 'Invalid',
     'CurrentPhaseA', 'PeakCurrentPhaseA', 'CurrentPhaseB',
     'PeakCurrentPhaseB', 'CurrentPhaseC', 'PeakCurrentPhaseC',
     'DifferentialPressure', 'Flow', 'Humidity', 'NodeTemperature',
     'NodeVoltage', 'PeakVibration', 'Pressure', 'RmsVibration',
     'SignalStrength', 'StandardAirVelocity', 'SupplyVoltage', 'Temperature',
     'TotalCurrent', 'VibrationXAxis', 'VibrationYAxis', 'Voltage', 'Current',
     'AtoDChannel1', 'AtoDChannel2', 'AtoDChannel3', 'AtoDChannel4',
     'AtoDChannel5', 'AtoDChannel6', 'OilTemperature', 'OilHumidity', 'X', 'Y',
     'Z', 'Custom', 'WirelessEfficiency', 'PacketSuccessRate', 'NodeHumidity',
     'BurstSuccessRate'
    :type running_speed_sensor_role_type: str or
     ~smartdiagnostics_sdk.models.enum
    :param running_speed_harmonic:
    :type running_speed_harmonic: float
    """

    _attribute_map = {
        'running_speed_min': {'key': 'RunningSpeedMin', 'type': 'float'},
        'running_speed_max': {'key': 'RunningSpeedMax', 'type': 'float'},
        'running_speed_type': {'key': 'RunningSpeedType', 'type': 'str'},
        'running_speed_reference_monitoring_point_id': {'key': 'RunningSpeedReferenceMonitoringPointId', 'type': 'str'},
        'running_speed_sensor_role_type': {'key': 'RunningSpeedSensorRoleType', 'type': 'str'},
        'running_speed_harmonic': {'key': 'RunningSpeedHarmonic', 'type': 'float'},
    }

    def __init__(self, *, running_speed_min: float=None, running_speed_max: float=None, running_speed_type: str=None, running_speed_reference_monitoring_point_id: str=None, running_speed_sensor_role_type=None, running_speed_harmonic: float=None, **kwargs) -> None:
        super(AssetRunningSpeedChild, self).__init__(**kwargs)
        self.running_speed_min = running_speed_min
        self.running_speed_max = running_speed_max
        self.running_speed_type = running_speed_type
        self.running_speed_reference_monitoring_point_id = running_speed_reference_monitoring_point_id
        self.running_speed_sensor_role_type = running_speed_sensor_role_type
        self.running_speed_harmonic = running_speed_harmonic
