# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardWidgetRequestChild(Model):
    """DashboardWidgetRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param dashboard_widget_id: Required.
    :type dashboard_widget_id: str
    :param dashboard_widget_row: Required.
    :type dashboard_widget_row: int
    :param dashboard_widget_column: Required.
    :type dashboard_widget_column: int
    :param dashboard_widget_height: Required.
    :type dashboard_widget_height: int
    :param dashboard_widget_width: Required.
    :type dashboard_widget_width: int
    """

    _validation = {
        'dashboard_widget_id': {'required': True},
        'dashboard_widget_row': {'required': True},
        'dashboard_widget_column': {'required': True},
        'dashboard_widget_height': {'required': True},
        'dashboard_widget_width': {'required': True},
    }

    _attribute_map = {
        'dashboard_widget_id': {'key': 'DashboardWidgetId', 'type': 'str'},
        'dashboard_widget_row': {'key': 'DashboardWidgetRow', 'type': 'int'},
        'dashboard_widget_column': {'key': 'DashboardWidgetColumn', 'type': 'int'},
        'dashboard_widget_height': {'key': 'DashboardWidgetHeight', 'type': 'int'},
        'dashboard_widget_width': {'key': 'DashboardWidgetWidth', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(DashboardWidgetRequestChild, self).__init__(**kwargs)
        self.dashboard_widget_id = kwargs.get('dashboard_widget_id', None)
        self.dashboard_widget_row = kwargs.get('dashboard_widget_row', None)
        self.dashboard_widget_column = kwargs.get('dashboard_widget_column', None)
        self.dashboard_widget_height = kwargs.get('dashboard_widget_height', None)
        self.dashboard_widget_width = kwargs.get('dashboard_widget_width', None)
