# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetTemplateChild(Model):
    """WidgetTemplateChild.

    All required parameters must be populated in order to send to Azure.

    :param widget_template_name: Required.
    :type widget_template_name: str
    :param widget_template_description:
    :type widget_template_description: str
    :param widget_template_filters:
    :type widget_template_filters:
     list[~smartdiagnostics_sdk.models.WidgetTemplateFilterChild]
    """

    _validation = {
        'widget_template_name': {'required': True},
    }

    _attribute_map = {
        'widget_template_name': {'key': 'WidgetTemplateName', 'type': 'str'},
        'widget_template_description': {'key': 'WidgetTemplateDescription', 'type': 'str'},
        'widget_template_filters': {'key': 'WidgetTemplateFilters', 'type': '[WidgetTemplateFilterChild]'},
    }

    def __init__(self, **kwargs):
        super(WidgetTemplateChild, self).__init__(**kwargs)
        self.widget_template_name = kwargs.get('widget_template_name', None)
        self.widget_template_description = kwargs.get('widget_template_description', None)
        self.widget_template_filters = kwargs.get('widget_template_filters', None)
