# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubNodeChild(Model):
    """HubNodeChild.

    :param node_id:
    :type node_id: long
    :param node_serial_number:
    :type node_serial_number: str
    :param node_nickname:
    :type node_nickname: str
    :param is_online:
    :type is_online: bool
    :param node_settings:
    :type node_settings: list[~smartdiagnostics_sdk.models.NodeSettingChild]
    :param latest_long_burst:
    :type latest_long_burst:
     ~smartdiagnostics_sdk.models.LongBurstRequestChild
    """

    _attribute_map = {
        'node_id': {'key': 'NodeId', 'type': 'long'},
        'node_serial_number': {'key': 'NodeSerialNumber', 'type': 'str'},
        'node_nickname': {'key': 'NodeNickname', 'type': 'str'},
        'is_online': {'key': 'IsOnline', 'type': 'bool'},
        'node_settings': {'key': 'NodeSettings', 'type': '[NodeSettingChild]'},
        'latest_long_burst': {'key': 'LatestLongBurst', 'type': 'LongBurstRequestChild'},
    }

    def __init__(self, **kwargs):
        super(HubNodeChild, self).__init__(**kwargs)
        self.node_id = kwargs.get('node_id', None)
        self.node_serial_number = kwargs.get('node_serial_number', None)
        self.node_nickname = kwargs.get('node_nickname', None)
        self.is_online = kwargs.get('is_online', None)
        self.node_settings = kwargs.get('node_settings', None)
        self.latest_long_burst = kwargs.get('latest_long_burst', None)
