# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetsStatusCountChild(Model):
    """AssetsStatusCountChild.

    :param normal:
    :type normal: int
    :param warning:
    :type warning: int
    :param alarm:
    :type alarm: int
    """

    _attribute_map = {
        'normal': {'key': 'Normal', 'type': 'int'},
        'warning': {'key': 'Warning', 'type': 'int'},
        'alarm': {'key': 'Alarm', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AssetsStatusCountChild, self).__init__(**kwargs)
        self.normal = kwargs.get('normal', None)
        self.warning = kwargs.get('warning', None)
        self.alarm = kwargs.get('alarm', None)
