# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EventModelV3(Model):
    """EventModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id:
    :type id: str
    :param location_id:
    :type location_id: str
    :param window_id:
    :type window_id: str
    :param date_occurred: Required.
    :type date_occurred: datetime
    :param description:
    :type description: str
    :param reason:
    :type reason: str
    :param content_type: Required. Possible values include: 'Invalid',
     'OperationalCondition', 'Fault', 'RootCause', 'Evidence', 'Inspection',
     'PreventativeMaintenance', 'CorrectiveMaintenance', 'Observation',
     'Document', 'Description', 'SamplingFrequencyChange',
     'PendingSamplingFrequencyChange', 'AutoInvalidBurstData',
     'UserInvalidBurstData'
    :type content_type: str or ~smartdiagnostics_sdk.models.enum
    :param attachment: Required.
    :type attachment: ~smartdiagnostics_sdk.models.AttachmentModelV3
    :param code_ids:
    :type code_ids: list[str]
    :param tag_details:
    :type tag_details: list[str]
    :param document_url:
    :type document_url: str
    :param document_name:
    :type document_name: str
    :param title:
    :type title: str
    :param evidence_indicator_id:
    :type evidence_indicator_id: str
    :param created:
    :type created: datetime
    :param created_by:
    :type created_by: str
    :param modified:
    :type modified: datetime
    :param modified_by:
    :type modified_by: str
    :param savings:
    :type savings: float
    :param group_name:
    :type group_name: str
    :param group_path:
    :type group_path: str
    :param group_type: Possible values include: 'Invalid', 'Group', 'Asset',
     'MonitoringPoint', 'IndicatorGroup', 'AnalyticModel'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'date_occurred': {'required': True},
        'content_type': {'required': True},
        'attachment': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'window_id': {'key': 'WindowId', 'type': 'str'},
        'date_occurred': {'key': 'DateOccurred', 'type': 'iso-8601'},
        'description': {'key': 'Description', 'type': 'str'},
        'reason': {'key': 'Reason', 'type': 'str'},
        'content_type': {'key': 'ContentType', 'type': 'str'},
        'attachment': {'key': 'Attachment', 'type': 'AttachmentModelV3'},
        'code_ids': {'key': 'CodeIds', 'type': '[str]'},
        'tag_details': {'key': 'TagDetails', 'type': '[str]'},
        'document_url': {'key': 'DocumentUrl', 'type': 'str'},
        'document_name': {'key': 'DocumentName', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
        'evidence_indicator_id': {'key': 'EvidenceIndicatorId', 'type': 'str'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'created_by': {'key': 'CreatedBy', 'type': 'str'},
        'modified': {'key': 'Modified', 'type': 'iso-8601'},
        'modified_by': {'key': 'ModifiedBy', 'type': 'str'},
        'savings': {'key': 'Savings', 'type': 'float'},
        'group_name': {'key': 'GroupName', 'type': 'str'},
        'group_path': {'key': 'GroupPath', 'type': 'str'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EventModelV3, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.location_id = kwargs.get('location_id', None)
        self.window_id = kwargs.get('window_id', None)
        self.date_occurred = kwargs.get('date_occurred', None)
        self.description = kwargs.get('description', None)
        self.reason = kwargs.get('reason', None)
        self.content_type = kwargs.get('content_type', None)
        self.attachment = kwargs.get('attachment', None)
        self.code_ids = kwargs.get('code_ids', None)
        self.tag_details = kwargs.get('tag_details', None)
        self.document_url = kwargs.get('document_url', None)
        self.document_name = kwargs.get('document_name', None)
        self.title = kwargs.get('title', None)
        self.evidence_indicator_id = kwargs.get('evidence_indicator_id', None)
        self.created = kwargs.get('created', None)
        self.created_by = kwargs.get('created_by', None)
        self.modified = kwargs.get('modified', None)
        self.modified_by = kwargs.get('modified_by', None)
        self.savings = kwargs.get('savings', None)
        self.group_name = kwargs.get('group_name', None)
        self.group_path = kwargs.get('group_path', None)
        self.group_type = kwargs.get('group_type', None)
