# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RepeaterNodeChild(Model):
    """RepeaterNodeChild.

    All required parameters must be populated in order to send to Azure.

    :param repeater_id: Required.
    :type repeater_id: long
    :param repeater_name:
    :type repeater_name: str
    :param repeater_serial_number: Required.
    :type repeater_serial_number: str
    """

    _validation = {
        'repeater_id': {'required': True},
        'repeater_serial_number': {'required': True, 'max_length': 8},
    }

    _attribute_map = {
        'repeater_id': {'key': 'RepeaterId', 'type': 'long'},
        'repeater_name': {'key': 'RepeaterName', 'type': 'str'},
        'repeater_serial_number': {'key': 'RepeaterSerialNumber', 'type': 'str'},
    }

    def __init__(self, *, repeater_id: int, repeater_serial_number: str, repeater_name: str=None, **kwargs) -> None:
        super(RepeaterNodeChild, self).__init__(**kwargs)
        self.repeater_id = repeater_id
        self.repeater_name = repeater_name
        self.repeater_serial_number = repeater_serial_number
