# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpdateBearingsForGroupRequest(Model):
    """UpdateBearingsForGroupRequest.

    All required parameters must be populated in order to send to Azure.

    :param bearing_ids: Required.
    :type bearing_ids: list[str]
    """

    _validation = {
        'bearing_ids': {'required': True},
    }

    _attribute_map = {
        'bearing_ids': {'key': 'BearingIds', 'type': '[str]'},
    }

    def __init__(self, *, bearing_ids, **kwargs) -> None:
        super(UpdateBearingsForGroupRequest, self).__init__(**kwargs)
        self.bearing_ids = bearing_ids
