# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CorporationIndustryChild(Model):
    """CorporationIndustryChild.

    All required parameters must be populated in order to send to Azure.

    :param industry_id: Required.
    :type industry_id: int
    :param industry_name: Required.
    :type industry_name: str
    """

    _validation = {
        'industry_id': {'required': True},
        'industry_name': {'required': True},
    }

    _attribute_map = {
        'industry_id': {'key': 'IndustryId', 'type': 'int'},
        'industry_name': {'key': 'IndustryName', 'type': 'str'},
    }

    def __init__(self, *, industry_id: int, industry_name: str, **kwargs) -> None:
        super(CorporationIndustryChild, self).__init__(**kwargs)
        self.industry_id = industry_id
        self.industry_name = industry_name
