# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointNodeChild(Model):
    """MonitoringPointNodeChild.

    :param node_id:
    :type node_id: long
    :param node_serial_number:
    :type node_serial_number: str
    :param node_nickname:
    :type node_nickname: str
    :param node_type_code: Possible values include: 'Invalid', 'KcfFlow',
     'KcfPressureVoltage', 'KcfPressureCurrent', 'KcfPower', 'KcfVibration',
     'KcfVibrationV1', 'KcfVoltage', 'KcfCurrent', 'KcfAtoDVoltage',
     'KcfAtoDCurrent', 'KcfOilQuality', 'Generic', 'KcfAgnostic',
     'KcfHumidity', 'KcfExtendedTemperatureVibration', 'KcfHubVibrationV1',
     'KcfHubAnalogAdapterV1'
    :type node_type_code: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'node_id': {'key': 'NodeId', 'type': 'long'},
        'node_serial_number': {'key': 'NodeSerialNumber', 'type': 'str'},
        'node_nickname': {'key': 'NodeNickname', 'type': 'str'},
        'node_type_code': {'key': 'NodeTypeCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MonitoringPointNodeChild, self).__init__(**kwargs)
        self.node_id = kwargs.get('node_id', None)
        self.node_serial_number = kwargs.get('node_serial_number', None)
        self.node_nickname = kwargs.get('node_nickname', None)
        self.node_type_code = kwargs.get('node_type_code', None)
