# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorChild(Model):
    """IndicatorChild.

    :param indicator_id:
    :type indicator_id: str
    :param indicator_name:
    :type indicator_name: str
    :param indicator_abbreviation:
    :type indicator_abbreviation: str
    """

    _attribute_map = {
        'indicator_id': {'key': 'IndicatorId', 'type': 'str'},
        'indicator_name': {'key': 'IndicatorName', 'type': 'str'},
        'indicator_abbreviation': {'key': 'IndicatorAbbreviation', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IndicatorChild, self).__init__(**kwargs)
        self.indicator_id = kwargs.get('indicator_id', None)
        self.indicator_name = kwargs.get('indicator_name', None)
        self.indicator_abbreviation = kwargs.get('indicator_abbreviation', None)
