# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodeStatusChild(Model):
    """InstallNodeStatusChild.

    :param status_id: The corresponding StatusId
    :type status_id: long
    :param status: The textual description of the Status
    :type status: str
    :param status_date: The DateTime that the current status was set as part
     of an install activity
    :type status_date: datetime
    :param status_note: A brief note about the installation of the node,
     typically used when
     something prevents a node from being installed to keep records
    :type status_note: str
    :param install_user: The user that set the current install status
    :type install_user: str
    """

    _attribute_map = {
        'status_id': {'key': 'StatusId', 'type': 'long'},
        'status': {'key': 'Status', 'type': 'str'},
        'status_date': {'key': 'StatusDate', 'type': 'iso-8601'},
        'status_note': {'key': 'StatusNote', 'type': 'str'},
        'install_user': {'key': 'InstallUser', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstallNodeStatusChild, self).__init__(**kwargs)
        self.status_id = kwargs.get('status_id', None)
        self.status = kwargs.get('status', None)
        self.status_date = kwargs.get('status_date', None)
        self.status_note = kwargs.get('status_note', None)
        self.install_user = kwargs.get('install_user', None)
