# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagChild(Model):
    """TagChild.

    :param tag_id:
    :type tag_id: str
    :param tag_name:
    :type tag_name: str
    :param tag_category: Possible values include: 'General', 'Components',
     'Make', 'Model', 'Location', 'Orientation', 'Asset', 'AssetCode',
     'Picture'
    :type tag_category: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'tag_name': {'max_length': 50},
    }

    _attribute_map = {
        'tag_id': {'key': 'TagId', 'type': 'str'},
        'tag_name': {'key': 'TagName', 'type': 'str'},
        'tag_category': {'key': 'TagCategory', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TagChild, self).__init__(**kwargs)
        self.tag_id = kwargs.get('tag_id', None)
        self.tag_name = kwargs.get('tag_name', None)
        self.tag_category = kwargs.get('tag_category', None)
