# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationResponse(Model):
    """LocationResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param active:
    :type active: bool
    :param created:
    :type created: datetime
    :param site_ids:
    :type site_ids: list[str]
    :param settings:
    :type settings: ~smartdiagnostics_sdk.models.LocationSettingsChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.PrimaryCorporationChild
    :param systems:
    :type systems: list[~smartdiagnostics_sdk.models.SystemChild]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'active': {'key': 'Active', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'site_ids': {'key': 'SiteIds', 'type': '[str]'},
        'settings': {'key': 'Settings', 'type': 'LocationSettingsChild'},
        'corporation': {'key': 'Corporation', 'type': 'PrimaryCorporationChild'},
        'systems': {'key': 'Systems', 'type': '[SystemChild]'},
    }

    def __init__(self, **kwargs):
        super(LocationResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.abbreviation = kwargs.get('abbreviation', None)
        self.active = kwargs.get('active', None)
        self.created = kwargs.get('created', None)
        self.site_ids = kwargs.get('site_ids', None)
        self.settings = kwargs.get('settings', None)
        self.corporation = kwargs.get('corporation', None)
        self.systems = kwargs.get('systems', None)
