# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExternalNotificationChild(Model):
    """ExternalNotificationChild.

    :param external_notification_id:
    :type external_notification_id: str
    :param external_notification_requested_time:
    :type external_notification_requested_time: datetime
    :param external_notification_user:
    :type external_notification_user: ~smartdiagnostics_sdk.models.UserChild
    """

    _attribute_map = {
        'external_notification_id': {'key': 'ExternalNotificationId', 'type': 'str'},
        'external_notification_requested_time': {'key': 'ExternalNotificationRequestedTime', 'type': 'iso-8601'},
        'external_notification_user': {'key': 'ExternalNotificationUser', 'type': 'UserChild'},
    }

    def __init__(self, **kwargs):
        super(ExternalNotificationChild, self).__init__(**kwargs)
        self.external_notification_id = kwargs.get('external_notification_id', None)
        self.external_notification_requested_time = kwargs.get('external_notification_requested_time', None)
        self.external_notification_user = kwargs.get('external_notification_user', None)
