# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodesStatusChild(Model):
    """InstallNodesStatusChild.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar total:
    :vartype total: int
    :param status:
    :type status: ~smartdiagnostics_sdk.models.NodeStatusChild
    """

    _validation = {
        'total': {'readonly': True},
    }

    _attribute_map = {
        'total': {'key': 'Total', 'type': 'int'},
        'status': {'key': 'Status', 'type': 'NodeStatusChild'},
    }

    def __init__(self, **kwargs):
        super(InstallNodesStatusChild, self).__init__(**kwargs)
        self.total = None
        self.status = kwargs.get('status', None)
