# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointAssignmentResponse(Model):
    """MonitoringPointAssignmentResponse.

    :param id:
    :type id: long
    :param start_date:
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    :param is_paused:
    :type is_paused: bool
    :param monitoring_point:
    :type monitoring_point: ~smartdiagnostics_sdk.models.MonitoringPointChild
    :param node:
    :type node: ~smartdiagnostics_sdk.models.MonitoringPointNodeChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'monitoring_point': {'key': 'MonitoringPoint', 'type': 'MonitoringPointChild'},
        'node': {'key': 'Node', 'type': 'MonitoringPointNodeChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, *, id: int=None, start_date=None, end_date=None, is_paused: bool=None, monitoring_point=None, node=None, corporation=None, location=None, **kwargs) -> None:
        super(MonitoringPointAssignmentResponse, self).__init__(**kwargs)
        self.id = id
        self.start_date = start_date
        self.end_date = end_date
        self.is_paused = is_paused
        self.monitoring_point = monitoring_point
        self.node = node
        self.corporation = corporation
        self.location = location
