# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveFilesRequest(Model):
    """MoveFilesRequest.

    All required parameters must be populated in order to send to Azure.

    :param file_ids: Required. File Ids to move
    :type file_ids: list[str]
    :param destination_folder_id: Required. File to move all files to (Parent
     Id)
    :type destination_folder_id: str
    """

    _validation = {
        'file_ids': {'required': True},
        'destination_folder_id': {'required': True},
    }

    _attribute_map = {
        'file_ids': {'key': 'FileIds', 'type': '[str]'},
        'destination_folder_id': {'key': 'DestinationFolderId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MoveFilesRequest, self).__init__(**kwargs)
        self.file_ids = kwargs.get('file_ids', None)
        self.destination_folder_id = kwargs.get('destination_folder_id', None)
