# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PicturesModelV3(Model):
    """PicturesModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param description:
    :type description: str
    :param name:
    :type name: str
    :param image_file_name:
    :type image_file_name: str
    :param thumbnail_file_name:
    :type thumbnail_file_name: str
    :param attachment:
    :type attachment: ~smartdiagnostics_sdk.models.AttachmentModelV3
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'image_file_name': {'key': 'ImageFileName', 'type': 'str'},
        'thumbnail_file_name': {'key': 'ThumbnailFileName', 'type': 'str'},
        'attachment': {'key': 'Attachment', 'type': 'AttachmentModelV3'},
    }

    def __init__(self, *, id: str, description: str=None, name: str=None, image_file_name: str=None, thumbnail_file_name: str=None, attachment=None, **kwargs) -> None:
        super(PicturesModelV3, self).__init__(**kwargs)
        self.id = id
        self.description = description
        self.name = name
        self.image_file_name = image_file_name
        self.thumbnail_file_name = thumbnail_file_name
        self.attachment = attachment
