# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubChild(Model):
    """HubChild.

    :param hub_serial_number:
    :type hub_serial_number: str
    :param hub_name:
    :type hub_name: str
    :param hub_port_number:
    :type hub_port_number: int
    """

    _attribute_map = {
        'hub_serial_number': {'key': 'HubSerialNumber', 'type': 'str'},
        'hub_name': {'key': 'HubName', 'type': 'str'},
        'hub_port_number': {'key': 'HubPortNumber', 'type': 'int'},
    }

    def __init__(self, *, hub_serial_number: str=None, hub_name: str=None, hub_port_number: int=None, **kwargs) -> None:
        super(HubChild, self).__init__(**kwargs)
        self.hub_serial_number = hub_serial_number
        self.hub_name = hub_name
        self.hub_port_number = hub_port_number
