# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ParentChild(Model):
    """ParentChild.

    :param parent_id:
    :type parent_id: str
    :param parent_name:
    :type parent_name: str
    :param parent_abbreviation:
    :type parent_abbreviation: str
    :param parent_type:
    :type parent_type: str
    """

    _attribute_map = {
        'parent_id': {'key': 'ParentId', 'type': 'str'},
        'parent_name': {'key': 'ParentName', 'type': 'str'},
        'parent_abbreviation': {'key': 'ParentAbbreviation', 'type': 'str'},
        'parent_type': {'key': 'ParentType', 'type': 'str'},
    }

    def __init__(self, *, parent_id: str=None, parent_name: str=None, parent_abbreviation: str=None, parent_type: str=None, **kwargs) -> None:
        super(ParentChild, self).__init__(**kwargs)
        self.parent_id = parent_id
        self.parent_name = parent_name
        self.parent_abbreviation = parent_abbreviation
        self.parent_type = parent_type
