# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAlertsResponse(Model):
    """GroupAlertsResponse.

    :param indicator_id:
    :type indicator_id: str
    :param indicator_name:
    :type indicator_name: str
    :param indicator_sort_order:
    :type indicator_sort_order: int
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param time_of_alert:
    :type time_of_alert: datetime
    :param external_notification:
    :type external_notification:
     ~smartdiagnostics_sdk.models.ExternalNotificationChild
    """

    _attribute_map = {
        'indicator_id': {'key': 'IndicatorId', 'type': 'str'},
        'indicator_name': {'key': 'IndicatorName', 'type': 'str'},
        'indicator_sort_order': {'key': 'IndicatorSortOrder', 'type': 'int'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'time_of_alert': {'key': 'TimeOfAlert', 'type': 'iso-8601'},
        'external_notification': {'key': 'ExternalNotification', 'type': 'ExternalNotificationChild'},
    }

    def __init__(self, *, indicator_id: str=None, indicator_name: str=None, indicator_sort_order: int=None, hierarchy=None, time_of_alert=None, external_notification=None, **kwargs) -> None:
        super(GroupAlertsResponse, self).__init__(**kwargs)
        self.indicator_id = indicator_id
        self.indicator_name = indicator_name
        self.indicator_sort_order = indicator_sort_order
        self.hierarchy = hierarchy
        self.time_of_alert = time_of_alert
        self.external_notification = external_notification
