# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LayoutChild(Model):
    """LayoutChild.

    All required parameters must be populated in order to send to Azure.

    :param layout_row: Required.
    :type layout_row: int
    :param layout_column: Required.
    :type layout_column: int
    :param layout_height: Required.
    :type layout_height: int
    :param layout_width: Required.
    :type layout_width: int
    """

    _validation = {
        'layout_row': {'required': True},
        'layout_column': {'required': True},
        'layout_height': {'required': True},
        'layout_width': {'required': True},
    }

    _attribute_map = {
        'layout_row': {'key': 'LayoutRow', 'type': 'int'},
        'layout_column': {'key': 'LayoutColumn', 'type': 'int'},
        'layout_height': {'key': 'LayoutHeight', 'type': 'int'},
        'layout_width': {'key': 'LayoutWidth', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(LayoutChild, self).__init__(**kwargs)
        self.layout_row = kwargs.get('layout_row', None)
        self.layout_column = kwargs.get('layout_column', None)
        self.layout_height = kwargs.get('layout_height', None)
        self.layout_width = kwargs.get('layout_width', None)
