# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BandDefinitionChild(Model):
    """BandDefinitionChild.

    :param high_band_frequency:
    :type high_band_frequency: float
    :param low_band_frequency:
    :type low_band_frequency: float
    """

    _attribute_map = {
        'high_band_frequency': {'key': 'HighBandFrequency', 'type': 'float'},
        'low_band_frequency': {'key': 'LowBandFrequency', 'type': 'float'},
    }

    def __init__(self, *, high_band_frequency: float=None, low_band_frequency: float=None, **kwargs) -> None:
        super(BandDefinitionChild, self).__init__(**kwargs)
        self.high_band_frequency = high_band_frequency
        self.low_band_frequency = low_band_frequency
