# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BearingChild(Model):
    """BearingChild.

    :param bearing_id:
    :type bearing_id: str
    :param bearing_name:
    :type bearing_name: str
    :param bearing_manufacturer:
    :type bearing_manufacturer: str
    :param bearing_bpfi:
    :type bearing_bpfi: float
    """

    _attribute_map = {
        'bearing_id': {'key': 'BearingId', 'type': 'str'},
        'bearing_name': {'key': 'BearingName', 'type': 'str'},
        'bearing_manufacturer': {'key': 'BearingManufacturer', 'type': 'str'},
        'bearing_bpfi': {'key': 'BearingBpfi', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(BearingChild, self).__init__(**kwargs)
        self.bearing_id = kwargs.get('bearing_id', None)
        self.bearing_name = kwargs.get('bearing_name', None)
        self.bearing_manufacturer = kwargs.get('bearing_manufacturer', None)
        self.bearing_bpfi = kwargs.get('bearing_bpfi', None)
