# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetTypeChild(Model):
    """WidgetTypeChild.

    All required parameters must be populated in order to send to Azure.

    :param widget_type_id: Required.
    :type widget_type_id: int
    :param widget_type_name: Required. Possible values include: 'Value',
     'Table', 'Kpi', 'Series'
    :type widget_type_name: str or ~smartdiagnostics_sdk.models.enum
    :param widget_type_description:
    :type widget_type_description: str
    """

    _validation = {
        'widget_type_id': {'required': True},
        'widget_type_name': {'required': True},
    }

    _attribute_map = {
        'widget_type_id': {'key': 'WidgetTypeId', 'type': 'int'},
        'widget_type_name': {'key': 'WidgetTypeName', 'type': 'str'},
        'widget_type_description': {'key': 'WidgetTypeDescription', 'type': 'str'},
    }

    def __init__(self, *, widget_type_id: int, widget_type_name, widget_type_description: str=None, **kwargs) -> None:
        super(WidgetTypeChild, self).__init__(**kwargs)
        self.widget_type_id = widget_type_id
        self.widget_type_name = widget_type_name
        self.widget_type_description = widget_type_description
