# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelIndicatorChild(Model):
    """AnalyticsModelIndicatorChild.

    All required parameters must be populated in order to send to Azure.

    :param indicator_name: Required.
    :type indicator_name: str
    :param indicator_units:
    :type indicator_units: str
    :param indicator_type: Required. Possible values include: 'Temperature',
     'Pressure', 'Flow', 'Humidity', 'Power', 'DifferentialPressure',
     'MultiSensorDifferentialPressure', 'Voltage', 'GeneralizedAtoD',
     'VibrationBandRms', 'VibrationBandMax', 'VibrationOverallPeak',
     'VibrationOverallRms', 'VibrationOverallSkewness',
     'VibrationOverallKurtosis', 'VibrationOverallCrestFactor',
     'DamageAccumulation', 'VibrationBandRmsAccel', 'VibrationBandMaxAccel',
     'VibrationOverallPeakAccel', 'VibrationOverallRmsAccel',
     'VibrationOverallSkewnessAccel', 'VibrationOverallKurtosisAccel',
     'VibrationOverallCrestFactorAccel', 'DamageAccumulationAccel', 'Group',
     'VibrationOverall', 'VibrationOverallAccel', 'GeneralTimeSeries', 'Math',
     'OnStatistics', 'OffStatistics', 'AlarmStatistics', 'WarningStatistics',
     'PositivePeakPressure', 'NegativePeakPressure', 'RmsPressure',
     'BandPressure', 'OnPercentStatistics', 'OffPercentStatistics',
     'AlarmPercentStatistics', 'WarningPercentStatistics', 'SignalStrength',
     'RunningSpeed', 'DamageAccumulationPressure', 'OilHumidity',
     'OilTemperature', 'DamageAccumulationAccelRaw', 'ThermalRegionOfInterest',
     'SmartMetric', 'Feature'
    :type indicator_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'indicator_name': {'required': True},
        'indicator_type': {'required': True},
    }

    _attribute_map = {
        'indicator_name': {'key': 'IndicatorName', 'type': 'str'},
        'indicator_units': {'key': 'IndicatorUnits', 'type': 'str'},
        'indicator_type': {'key': 'IndicatorType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelIndicatorChild, self).__init__(**kwargs)
        self.indicator_name = kwargs.get('indicator_name', None)
        self.indicator_units = kwargs.get('indicator_units', None)
        self.indicator_type = kwargs.get('indicator_type', None)
