# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeRangeModelV3(Model):
    """TimeRangeModelV3.

    :param start_date:
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _attribute_map = {
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, start_date=None, end_date=None, **kwargs) -> None:
        super(TimeRangeModelV3, self).__init__(**kwargs)
        self.start_date = start_date
        self.end_date = end_date
