# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserChild(Model):
    """UserChild.

    :param user_id:
    :type user_id: str
    :param user_first_name:
    :type user_first_name: str
    :param user_last_name:
    :type user_last_name: str
    :param user_email:
    :type user_email: str
    """

    _attribute_map = {
        'user_id': {'key': 'UserId', 'type': 'str'},
        'user_first_name': {'key': 'UserFirstName', 'type': 'str'},
        'user_last_name': {'key': 'UserLastName', 'type': 'str'},
        'user_email': {'key': 'UserEmail', 'type': 'str'},
    }

    def __init__(self, *, user_id: str=None, user_first_name: str=None, user_last_name: str=None, user_email: str=None, **kwargs) -> None:
        super(UserChild, self).__init__(**kwargs)
        self.user_id = user_id
        self.user_first_name = user_first_name
        self.user_last_name = user_last_name
        self.user_email = user_email
