# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointChild(Model):
    """MonitoringPointChild.

    :param monitoring_point_id:
    :type monitoring_point_id: str
    :param monitoring_point_name:
    :type monitoring_point_name: str
    :param monitoring_point_abbreviation:
    :type monitoring_point_abbreviation: str
    :param monitoring_point_type: Possible values include: 'Custom',
     'Vibration', 'Pressure', 'OilQuality', 'GeneralInput', 'IndicatorBased',
     'GeneralAtoD'
    :type monitoring_point_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'monitoring_point_id': {'key': 'MonitoringPointId', 'type': 'str'},
        'monitoring_point_name': {'key': 'MonitoringPointName', 'type': 'str'},
        'monitoring_point_abbreviation': {'key': 'MonitoringPointAbbreviation', 'type': 'str'},
        'monitoring_point_type': {'key': 'MonitoringPointType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MonitoringPointChild, self).__init__(**kwargs)
        self.monitoring_point_id = kwargs.get('monitoring_point_id', None)
        self.monitoring_point_name = kwargs.get('monitoring_point_name', None)
        self.monitoring_point_abbreviation = kwargs.get('monitoring_point_abbreviation', None)
        self.monitoring_point_type = kwargs.get('monitoring_point_type', None)
