# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertyResponse(Model):
    """PropertyResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param name: Required.
    :type name: str
    :param value_type: Required.
    :type value_type: str
    :param description:
    :type description: str
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'value_type': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'name': {'key': 'Name', 'type': 'str'},
        'value_type': {'key': 'ValueType', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
    }

    def __init__(self, *, id: int, name: str, value_type: str, description: str=None, **kwargs) -> None:
        super(PropertyResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.value_type = value_type
        self.description = description
