# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PersonalAccessTokenCreateRequest(Model):
    """PersonalAccessTokenCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param description: Required.
    :type description: str
    """

    _validation = {
        'description': {'required': True},
    }

    _attribute_map = {
        'description': {'key': 'Description', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PersonalAccessTokenCreateRequest, self).__init__(**kwargs)
        self.description = kwargs.get('description', None)
