# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilesError(Model):
    """FilesError.

    :param file_id:
    :type file_id: str
    :param display_name:
    :type display_name: str
    :param message:
    :type message: str
    """

    _attribute_map = {
        'file_id': {'key': 'FileId', 'type': 'str'},
        'display_name': {'key': 'DisplayName', 'type': 'str'},
        'message': {'key': 'Message', 'type': 'str'},
    }

    def __init__(self, *, file_id: str=None, display_name: str=None, message: str=None, **kwargs) -> None:
        super(FilesError, self).__init__(**kwargs)
        self.file_id = file_id
        self.display_name = display_name
        self.message = message
