# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DescendantChild(Model):
    """DescendantChild.

    :param child_id:
    :type child_id: str
    :param child_name:
    :type child_name: str
    :param child_abbreviation:
    :type child_abbreviation: str
    :param child_type: Possible values include: 'Asset', 'MonitoringPoint',
     'IndicatorGroup', 'Group', 'AnalyticModel'
    :type child_type: str or ~smartdiagnostics_sdk.models.enum
    :param child_sort_order:
    :type child_sort_order: int
    :param child_has_children:
    :type child_has_children: bool
    :param child_alarm_severity_level:
    :type child_alarm_severity_level: int
    :param child_is_paused:
    :type child_is_paused: bool
    :param child_is_snoozed:
    :type child_is_snoozed: bool
    """

    _attribute_map = {
        'child_id': {'key': 'ChildId', 'type': 'str'},
        'child_name': {'key': 'ChildName', 'type': 'str'},
        'child_abbreviation': {'key': 'ChildAbbreviation', 'type': 'str'},
        'child_type': {'key': 'ChildType', 'type': 'str'},
        'child_sort_order': {'key': 'ChildSortOrder', 'type': 'int'},
        'child_has_children': {'key': 'ChildHasChildren', 'type': 'bool'},
        'child_alarm_severity_level': {'key': 'ChildAlarmSeverityLevel', 'type': 'int'},
        'child_is_paused': {'key': 'ChildIsPaused', 'type': 'bool'},
        'child_is_snoozed': {'key': 'ChildIsSnoozed', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DescendantChild, self).__init__(**kwargs)
        self.child_id = kwargs.get('child_id', None)
        self.child_name = kwargs.get('child_name', None)
        self.child_abbreviation = kwargs.get('child_abbreviation', None)
        self.child_type = kwargs.get('child_type', None)
        self.child_sort_order = kwargs.get('child_sort_order', None)
        self.child_has_children = kwargs.get('child_has_children', None)
        self.child_alarm_severity_level = kwargs.get('child_alarm_severity_level', None)
        self.child_is_paused = kwargs.get('child_is_paused', None)
        self.child_is_snoozed = kwargs.get('child_is_snoozed', None)
