# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareStatusChild(Model):
    """HardwareStatusChild.

    :param location_id:
    :type location_id: str
    :param location_name:
    :type location_name: str
    :param location_abbreviation:
    :type location_abbreviation: str
    :param hardware_count:
    :type hardware_count: int
    :param unassigned_count:
    :type unassigned_count: int
    :param online_count:
    :type online_count: int
    :param offline_count:
    :type offline_count: int
    """

    _attribute_map = {
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'location_abbreviation': {'key': 'LocationAbbreviation', 'type': 'str'},
        'hardware_count': {'key': 'HardwareCount', 'type': 'int'},
        'unassigned_count': {'key': 'UnassignedCount', 'type': 'int'},
        'online_count': {'key': 'OnlineCount', 'type': 'int'},
        'offline_count': {'key': 'OfflineCount', 'type': 'int'},
    }

    def __init__(self, *, location_id: str=None, location_name: str=None, location_abbreviation: str=None, hardware_count: int=None, unassigned_count: int=None, online_count: int=None, offline_count: int=None, **kwargs) -> None:
        super(HardwareStatusChild, self).__init__(**kwargs)
        self.location_id = location_id
        self.location_name = location_name
        self.location_abbreviation = location_abbreviation
        self.hardware_count = hardware_count
        self.unassigned_count = unassigned_count
        self.online_count = online_count
        self.offline_count = offline_count
