# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupMoveRequest(Model):
    """GroupMoveRequest.

    All required parameters must be populated in order to send to Azure.

    :param sort_order: Required.
    :type sort_order: int
    :param parent_id: Required.
    :type parent_id: str
    """

    _validation = {
        'sort_order': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'parent_id': {'required': True},
    }

    _attribute_map = {
        'sort_order': {'key': 'SortOrder', 'type': 'int'},
        'parent_id': {'key': 'ParentId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GroupMoveRequest, self).__init__(**kwargs)
        self.sort_order = kwargs.get('sort_order', None)
        self.parent_id = kwargs.get('parent_id', None)
