# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingChild(Model):
    """NodeSettingChild.

    :param node_setting_name:
    :type node_setting_name: str
    :param node_setting_current_value:
    :type node_setting_current_value: str
    :param node_setting_pending_value:
    :type node_setting_pending_value: str
    """

    _attribute_map = {
        'node_setting_name': {'key': 'NodeSettingName', 'type': 'str'},
        'node_setting_current_value': {'key': 'NodeSettingCurrentValue', 'type': 'str'},
        'node_setting_pending_value': {'key': 'NodeSettingPendingValue', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(NodeSettingChild, self).__init__(**kwargs)
        self.node_setting_name = kwargs.get('node_setting_name', None)
        self.node_setting_current_value = kwargs.get('node_setting_current_value', None)
        self.node_setting_pending_value = kwargs.get('node_setting_pending_value', None)
