# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TargetedSoftwareReleaseChild(Model):
    """TargetedSoftwareReleaseChild.

    :param targeted_software_release_id:
    :type targeted_software_release_id: int
    :param targeted_software_release_name:
    :type targeted_software_release_name: str
    """

    _attribute_map = {
        'targeted_software_release_id': {'key': 'TargetedSoftwareReleaseId', 'type': 'int'},
        'targeted_software_release_name': {'key': 'TargetedSoftwareReleaseName', 'type': 'str'},
    }

    def __init__(self, *, targeted_software_release_id: int=None, targeted_software_release_name: str=None, **kwargs) -> None:
        super(TargetedSoftwareReleaseChild, self).__init__(**kwargs)
        self.targeted_software_release_id = targeted_software_release_id
        self.targeted_software_release_name = targeted_software_release_name
