# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelChild(Model):
    """AnalyticsModelChild.

    All required parameters must be populated in order to send to Azure.

    :param analytics_model_id: Required.
    :type analytics_model_id: int
    :param analytics_model_name: Required.
    :type analytics_model_name: str
    :param analytics_model_version: Required.
    :type analytics_model_version: str
    """

    _validation = {
        'analytics_model_id': {'required': True},
        'analytics_model_name': {'required': True},
        'analytics_model_version': {'required': True},
    }

    _attribute_map = {
        'analytics_model_id': {'key': 'AnalyticsModelId', 'type': 'int'},
        'analytics_model_name': {'key': 'AnalyticsModelName', 'type': 'str'},
        'analytics_model_version': {'key': 'AnalyticsModelVersion', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelChild, self).__init__(**kwargs)
        self.analytics_model_id = kwargs.get('analytics_model_id', None)
        self.analytics_model_name = kwargs.get('analytics_model_name', None)
        self.analytics_model_version = kwargs.get('analytics_model_version', None)
