# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetDrumRollChild(Model):
    """AssetDrumRollChild.

    :param drum_roll_diameter:
    :type drum_roll_diameter: int
    :param drum_roll_diameter_unit:
    :type drum_roll_diameter_unit: str
    """

    _attribute_map = {
        'drum_roll_diameter': {'key': 'DrumRollDiameter', 'type': 'int'},
        'drum_roll_diameter_unit': {'key': 'DrumRollDiameterUnit', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AssetDrumRollChild, self).__init__(**kwargs)
        self.drum_roll_diameter = kwargs.get('drum_roll_diameter', None)
        self.drum_roll_diameter_unit = kwargs.get('drum_roll_diameter_unit', None)
