# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupAnalyticsModelUpdateRequest(Model):
    """GroupAnalyticsModelUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param properties: Required.
    :type properties: list[~smartdiagnostics_sdk.models.SetPropertyChild]
    """

    _validation = {
        'properties': {'required': True},
    }

    _attribute_map = {
        'properties': {'key': 'Properties', 'type': '[SetPropertyChild]'},
    }

    def __init__(self, *, properties, **kwargs) -> None:
        super(GroupAnalyticsModelUpdateRequest, self).__init__(**kwargs)
        self.properties = properties
