# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PersonalAccessTokenResponse(Model):
    """PersonalAccessTokenResponse.

    :param id:
    :type id: str
    :param description:
    :type description: str
    :param created:
    :type created: datetime
    :param updated:
    :type updated: datetime
    :param last_used:
    :type last_used: datetime
    :param active:
    :type active: bool
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'last_used': {'key': 'LastUsed', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
    }

    def __init__(self, *, id: str=None, description: str=None, created=None, updated=None, last_used=None, active: bool=None, **kwargs) -> None:
        super(PersonalAccessTokenResponse, self).__init__(**kwargs)
        self.id = id
        self.description = description
        self.created = created
        self.updated = updated
        self.last_used = last_used
        self.active = active
