# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DocumentChild(Model):
    """DocumentChild.

    :param document_url:
    :type document_url: str
    :param document_name:
    :type document_name: str
    """

    _attribute_map = {
        'document_url': {'key': 'DocumentUrl', 'type': 'str'},
        'document_name': {'key': 'DocumentName', 'type': 'str'},
    }

    def __init__(self, *, document_url: str=None, document_name: str=None, **kwargs) -> None:
        super(DocumentChild, self).__init__(**kwargs)
        self.document_url = document_url
        self.document_name = document_name
