# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupChild(Model):
    """GroupChild.

    All required parameters must be populated in order to send to Azure.

    :param group_id: Required.
    :type group_id: str
    :param group_name: Required.
    :type group_name: str
    :param group_abbreviation:
    :type group_abbreviation: str
    :param group_type: Required. Possible values include: 'Asset',
     'MonitoringPoint', 'IndicatorGroup', 'Group', 'AnalyticModel'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'group_id': {'required': True},
        'group_name': {'required': True},
        'group_type': {'required': True},
    }

    _attribute_map = {
        'group_id': {'key': 'GroupId', 'type': 'str'},
        'group_name': {'key': 'GroupName', 'type': 'str'},
        'group_abbreviation': {'key': 'GroupAbbreviation', 'type': 'str'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(GroupChild, self).__init__(**kwargs)
        self.group_id = kwargs.get('group_id', None)
        self.group_name = kwargs.get('group_name', None)
        self.group_abbreviation = kwargs.get('group_abbreviation', None)
        self.group_type = kwargs.get('group_type', None)
