# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OverviewHierarchyChild(Model):
    """OverviewHierarchyChild.

    :param hierarchy_id:
    :type hierarchy_id: str
    :param hierarchy_name:
    :type hierarchy_name: str
    :param hierarchy_abbreviation:
    :type hierarchy_abbreviation: str
    :param hierarchy_type:
    :type hierarchy_type: str
    """

    _attribute_map = {
        'hierarchy_id': {'key': 'HierarchyId', 'type': 'str'},
        'hierarchy_name': {'key': 'HierarchyName', 'type': 'str'},
        'hierarchy_abbreviation': {'key': 'HierarchyAbbreviation', 'type': 'str'},
        'hierarchy_type': {'key': 'HierarchyType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(OverviewHierarchyChild, self).__init__(**kwargs)
        self.hierarchy_id = kwargs.get('hierarchy_id', None)
        self.hierarchy_name = kwargs.get('hierarchy_name', None)
        self.hierarchy_abbreviation = kwargs.get('hierarchy_abbreviation', None)
        self.hierarchy_type = kwargs.get('hierarchy_type', None)
