# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveFilesResponse(Model):
    """MoveFilesResponse.

    :param destination_folder_id:
    :type destination_folder_id: str
    :param success_count:
    :type success_count: int
    :param error_count:
    :type error_count: int
    :param errors:
    :type errors: list[~smartdiagnostics_sdk.models.FilesError]
    """

    _attribute_map = {
        'destination_folder_id': {'key': 'DestinationFolderId', 'type': 'str'},
        'success_count': {'key': 'SuccessCount', 'type': 'int'},
        'error_count': {'key': 'ErrorCount', 'type': 'int'},
        'errors': {'key': 'Errors', 'type': '[FilesError]'},
    }

    def __init__(self, **kwargs):
        super(MoveFilesResponse, self).__init__(**kwargs)
        self.destination_folder_id = kwargs.get('destination_folder_id', None)
        self.success_count = kwargs.get('success_count', None)
        self.error_count = kwargs.get('error_count', None)
        self.errors = kwargs.get('errors', None)
