# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagCreateRequest(Model):
    """TagCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param type: Required. Possible values include: 'General', 'Components',
     'Make', 'Model', 'Location', 'Orientation', 'Asset', 'AssetCode',
     'Picture'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param location_id: Required.
    :type location_id: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'type': {'required': True},
        'location_id': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'type': {'key': 'Type', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
    }

    def __init__(self, *, name: str, type, location_id: str, **kwargs) -> None:
        super(TagCreateRequest, self).__init__(**kwargs)
        self.name = name
        self.type = type
        self.location_id = location_id
