# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttachmentModelV3(Model):
    """AttachmentModelV3.

    All required parameters must be populated in order to send to Azure.

    :param type: Possible values include: 'Corporation', 'Account', 'Group',
     'Other', 'Indicator'
    :type type: str or ~smartdiagnostics_sdk.models.enum
    :param id: Required.
    :type id: str
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'type': {'key': 'Type', 'type': 'str'},
        'id': {'key': 'Id', 'type': 'str'},
    }

    def __init__(self, *, id: str, type=None, **kwargs) -> None:
        super(AttachmentModelV3, self).__init__(**kwargs)
        self.type = type
        self.id = id
