# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityCodeChild(Model):
    """ActivityCodeChild.

    :param activity_code_id:
    :type activity_code_id: str
    :param activity_code_name:
    :type activity_code_name: str
    """

    _attribute_map = {
        'activity_code_id': {'key': 'ActivityCodeId', 'type': 'str'},
        'activity_code_name': {'key': 'ActivityCodeName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityCodeChild, self).__init__(**kwargs)
        self.activity_code_id = kwargs.get('activity_code_id', None)
        self.activity_code_name = kwargs.get('activity_code_name', None)
