# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertyRequestChild(Model):
    """PropertyRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param property_name: Required.
    :type property_name: str
    :param property_value_type: Required. Possible values include: 'Boolean',
     'DateTime', 'Double', 'Float', 'Integer', 'String'
    :type property_value_type: str or ~smartdiagnostics_sdk.models.enum
    :param property_required: Required.
    :type property_required: bool
    """

    _validation = {
        'property_name': {'required': True},
        'property_value_type': {'required': True},
        'property_required': {'required': True},
    }

    _attribute_map = {
        'property_name': {'key': 'PropertyName', 'type': 'str'},
        'property_value_type': {'key': 'PropertyValueType', 'type': 'str'},
        'property_required': {'key': 'PropertyRequired', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(PropertyRequestChild, self).__init__(**kwargs)
        self.property_name = kwargs.get('property_name', None)
        self.property_value_type = kwargs.get('property_value_type', None)
        self.property_required = kwargs.get('property_required', None)
