# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallAddUserResponse(Model):
    """InstallAddUserResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param install_id:
    :type install_id: str
    :ivar success_count:
    :vartype success_count: int
    :ivar error_count:
    :vartype error_count: int
    """

    _validation = {
        'success_count': {'readonly': True},
        'error_count': {'readonly': True},
    }

    _attribute_map = {
        'install_id': {'key': 'InstallId', 'type': 'str'},
        'success_count': {'key': 'SuccessCount', 'type': 'int'},
        'error_count': {'key': 'ErrorCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(InstallAddUserResponse, self).__init__(**kwargs)
        self.install_id = kwargs.get('install_id', None)
        self.success_count = None
        self.error_count = None
