# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemChild(Model):
    """SystemChild.

    All required parameters must be populated in order to send to Azure.

    :param system_id: Required.
    :type system_id: str
    :param system_name: Required.
    :type system_name: str
    :param system_abbreviation:
    :type system_abbreviation: str
    """

    _validation = {
        'system_id': {'required': True},
        'system_name': {'required': True},
    }

    _attribute_map = {
        'system_id': {'key': 'SystemId', 'type': 'str'},
        'system_name': {'key': 'SystemName', 'type': 'str'},
        'system_abbreviation': {'key': 'SystemAbbreviation', 'type': 'str'},
    }

    def __init__(self, *, system_id: str, system_name: str, system_abbreviation: str=None, **kwargs) -> None:
        super(SystemChild, self).__init__(**kwargs)
        self.system_id = system_id
        self.system_name = system_name
        self.system_abbreviation = system_abbreviation
