# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemAssetsStatusSummaryResponse(Model):
    """SystemAssetsStatusSummaryResponse.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param system:
    :type system: ~smartdiagnostics_sdk.models.SystemChild
    :ivar asset_count:
    :vartype asset_count: int
    :param status_count:
    :type status_count: ~smartdiagnostics_sdk.models.AssetsStatusCountChild
    :param status_percentage:
    :type status_percentage:
     ~smartdiagnostics_sdk.models.AssetsStatusPercentageChild
    """

    _validation = {
        'asset_count': {'readonly': True},
    }

    _attribute_map = {
        'system': {'key': 'System', 'type': 'SystemChild'},
        'asset_count': {'key': 'AssetCount', 'type': 'int'},
        'status_count': {'key': 'StatusCount', 'type': 'AssetsStatusCountChild'},
        'status_percentage': {'key': 'StatusPercentage', 'type': 'AssetsStatusPercentageChild'},
    }

    def __init__(self, *, system=None, status_count=None, status_percentage=None, **kwargs) -> None:
        super(SystemAssetsStatusSummaryResponse, self).__init__(**kwargs)
        self.system = system
        self.asset_count = None
        self.status_count = status_count
        self.status_percentage = status_percentage
