# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReleaseRingChild(Model):
    """ReleaseRingChild.

    :param release_ring_id:
    :type release_ring_id: str
    :param release_ring_name:
    :type release_ring_name: str
    """

    _attribute_map = {
        'release_ring_id': {'key': 'ReleaseRingId', 'type': 'str'},
        'release_ring_name': {'key': 'ReleaseRingName', 'type': 'str'},
    }

    def __init__(self, *, release_ring_id: str=None, release_ring_name: str=None, **kwargs) -> None:
        super(ReleaseRingChild, self).__init__(**kwargs)
        self.release_ring_id = release_ring_id
        self.release_ring_name = release_ring_name
