# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorFilterUpdateRequest(Model):
    """IndicatorFilterUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param indicator_types:
    :type indicator_types: list[str]
    :param sort_order:
    :type sort_order: int
    :param tag_ids:
    :type tag_ids: list[str]
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'indicator_types': {'key': 'IndicatorTypes', 'type': '[str]'},
        'sort_order': {'key': 'SortOrder', 'type': 'int'},
        'tag_ids': {'key': 'TagIds', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(IndicatorFilterUpdateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.indicator_types = kwargs.get('indicator_types', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.tag_ids = kwargs.get('tag_ids', None)
