# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelRelatedModelChild(Model):
    """AnalyticsModelRelatedModelChild.

    :param related_model_id:
    :type related_model_id: int
    :param related_model_name:
    :type related_model_name: str
    :param related_model_type: Possible values include: 'SMARTIndicator',
     'Classifier'
    :type related_model_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'related_model_id': {'key': 'RelatedModelId', 'type': 'int'},
        'related_model_name': {'key': 'RelatedModelName', 'type': 'str'},
        'related_model_type': {'key': 'RelatedModelType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelRelatedModelChild, self).__init__(**kwargs)
        self.related_model_id = kwargs.get('related_model_id', None)
        self.related_model_name = kwargs.get('related_model_name', None)
        self.related_model_type = kwargs.get('related_model_type', None)
