# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCriticalityChild(Model):
    """AssetCriticalityChild.

    :param criticality_id:
    :type criticality_id: int
    :param criticality_name:
    :type criticality_name: str
    """

    _attribute_map = {
        'criticality_id': {'key': 'CriticalityId', 'type': 'int'},
        'criticality_name': {'key': 'CriticalityName', 'type': 'str'},
    }

    def __init__(self, *, criticality_id: int=None, criticality_name: str=None, **kwargs) -> None:
        super(AssetCriticalityChild, self).__init__(**kwargs)
        self.criticality_id = criticality_id
        self.criticality_name = criticality_name
