# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TriggerChild(Model):
    """TriggerChild.

    All required parameters must be populated in order to send to Azure.

    :param trigger_type: Required. Possible values include: 'Time',
     'NumberOfBurst', 'LinkedSensors'
    :type trigger_type: str or ~smartdiagnostics_sdk.models.enum
    :param trigger_value: Required.
    :type trigger_value: long
    """

    _validation = {
        'trigger_type': {'required': True},
        'trigger_value': {'required': True},
    }

    _attribute_map = {
        'trigger_type': {'key': 'TriggerType', 'type': 'str'},
        'trigger_value': {'key': 'TriggerValue', 'type': 'long'},
    }

    def __init__(self, *, trigger_type, trigger_value: int, **kwargs) -> None:
        super(TriggerChild, self).__init__(**kwargs)
        self.trigger_type = trigger_type
        self.trigger_value = trigger_value
