# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TreeItemChild(Model):
    """TreeItemChild.

    :param tree_item_id:
    :type tree_item_id: str
    :param tree_item_name:
    :type tree_item_name: str
    :param tree_item_abbreviation:
    :type tree_item_abbreviation: str
    """

    _attribute_map = {
        'tree_item_id': {'key': 'TreeItemId', 'type': 'str'},
        'tree_item_name': {'key': 'TreeItemName', 'type': 'str'},
        'tree_item_abbreviation': {'key': 'TreeItemAbbreviation', 'type': 'str'},
    }

    def __init__(self, *, tree_item_id: str=None, tree_item_name: str=None, tree_item_abbreviation: str=None, **kwargs) -> None:
        super(TreeItemChild, self).__init__(**kwargs)
        self.tree_item_id = tree_item_id
        self.tree_item_name = tree_item_name
        self.tree_item_abbreviation = tree_item_abbreviation
