# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CurrentSoftwareReleaseChild(Model):
    """CurrentSoftwareReleaseChild.

    :param current_software_release_id:
    :type current_software_release_id: int
    :param current_software_release_name:
    :type current_software_release_name: str
    """

    _attribute_map = {
        'current_software_release_id': {'key': 'CurrentSoftwareReleaseId', 'type': 'int'},
        'current_software_release_name': {'key': 'CurrentSoftwareReleaseName', 'type': 'str'},
    }

    def __init__(self, *, current_software_release_id: int=None, current_software_release_name: str=None, **kwargs) -> None:
        super(CurrentSoftwareReleaseChild, self).__init__(**kwargs)
        self.current_software_release_id = current_software_release_id
        self.current_software_release_name = current_software_release_name
