# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallUpdateRequest(Model):
    """InstallUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param start_date: Required.
    :type start_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'start_date': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'start_date': {'key': 'StartDate', 'type': 'iso-8601'},
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(InstallUpdateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)
