# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorAlarmStateResponse(Model):
    """IndicatorAlarmStateResponse.

    All required parameters must be populated in order to send to Azure.

    :param current_value: Current Value of indicator
    :type current_value: float
    :param last_update: Last time it was updated
    :type last_update: datetime
    :param id: Required. Id of entity
    :type id: str
    :param alarm_severity: Alarm severity
    :type alarm_severity: int
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'current_value': {'key': 'CurrentValue', 'type': 'float'},
        'last_update': {'key': 'LastUpdate', 'type': 'iso-8601'},
        'id': {'key': 'Id', 'type': 'str'},
        'alarm_severity': {'key': 'AlarmSeverity', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(IndicatorAlarmStateResponse, self).__init__(**kwargs)
        self.current_value = kwargs.get('current_value', None)
        self.last_update = kwargs.get('last_update', None)
        self.id = kwargs.get('id', None)
        self.alarm_severity = kwargs.get('alarm_severity', None)
