# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeSettingOverview(Model):
    """NodeSettingOverview.

    :param update_interval:
    :type update_interval: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param decimation_factor:
    :type decimation_factor: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param operating_mode_pressure:
    :type operating_mode_pressure:
     ~smartdiagnostics_sdk.models.NodeSettingValues
    :param operating_mode_vibration:
    :type operating_mode_vibration:
     ~smartdiagnostics_sdk.models.NodeSettingValues
    :param number_of_samples:
    :type number_of_samples: ~smartdiagnostics_sdk.models.NodeSettingValues
    :param compression_type:
    :type compression_type: ~smartdiagnostics_sdk.models.NodeSettingValues
    """

    _attribute_map = {
        'update_interval': {'key': 'UpdateInterval', 'type': 'NodeSettingValues'},
        'decimation_factor': {'key': 'DecimationFactor', 'type': 'NodeSettingValues'},
        'operating_mode_pressure': {'key': 'OperatingModePressure', 'type': 'NodeSettingValues'},
        'operating_mode_vibration': {'key': 'OperatingModeVibration', 'type': 'NodeSettingValues'},
        'number_of_samples': {'key': 'NumberOfSamples', 'type': 'NodeSettingValues'},
        'compression_type': {'key': 'CompressionType', 'type': 'NodeSettingValues'},
    }

    def __init__(self, *, update_interval=None, decimation_factor=None, operating_mode_pressure=None, operating_mode_vibration=None, number_of_samples=None, compression_type=None, **kwargs) -> None:
        super(NodeSettingOverview, self).__init__(**kwargs)
        self.update_interval = update_interval
        self.decimation_factor = decimation_factor
        self.operating_mode_pressure = operating_mode_pressure
        self.operating_mode_vibration = operating_mode_vibration
        self.number_of_samples = number_of_samples
        self.compression_type = compression_type
