# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PowerBiReportChild(Model):
    """PowerBiReportChild.

    :param power_bi_report_access_token:
    :type power_bi_report_access_token: str
    :param power_bi_report_name:
    :type power_bi_report_name: str
    :param power_bi_report_url:
    :type power_bi_report_url: str
    :param power_bi_report_embed_url:
    :type power_bi_report_embed_url: str
    :param error: Possible values include: 'None', 'ReportNotFound', 'Other'
    :type error: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'power_bi_report_access_token': {'key': 'PowerBiReportAccessToken', 'type': 'str'},
        'power_bi_report_name': {'key': 'PowerBiReportName', 'type': 'str'},
        'power_bi_report_url': {'key': 'PowerBiReportUrl', 'type': 'str'},
        'power_bi_report_embed_url': {'key': 'PowerBiReportEmbedUrl', 'type': 'str'},
        'error': {'key': 'Error', 'type': 'str'},
    }

    def __init__(self, *, power_bi_report_access_token: str=None, power_bi_report_name: str=None, power_bi_report_url: str=None, power_bi_report_embed_url: str=None, error=None, **kwargs) -> None:
        super(PowerBiReportChild, self).__init__(**kwargs)
        self.power_bi_report_access_token = power_bi_report_access_token
        self.power_bi_report_name = power_bi_report_name
        self.power_bi_report_url = power_bi_report_url
        self.power_bi_report_embed_url = power_bi_report_embed_url
        self.error = error
