# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MarkerUpdateRequest(Model):
    """MarkerUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param marker_type: Required. Possible values include: 'Fixed',
     'Multiplier'
    :type marker_type: str or ~smartdiagnostics_sdk.models.enum
    :param value: Required.
    :type value: float
    :param order: Required.
    :type order: int
    """

    _validation = {
        'name': {'required': True, 'max_length': 5},
        'marker_type': {'required': True},
        'value': {'required': True, 'minimum': 0},
        'order': {'required': True, 'maximum': 100, 'minimum': 0},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'marker_type': {'key': 'MarkerType', 'type': 'str'},
        'value': {'key': 'Value', 'type': 'float'},
        'order': {'key': 'Order', 'type': 'int'},
    }

    def __init__(self, *, name: str, marker_type, value: float, order: int, **kwargs) -> None:
        super(MarkerUpdateRequest, self).__init__(**kwargs)
        self.name = name
        self.marker_type = marker_type
        self.value = value
        self.order = order
