# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCategoryChild(Model):
    """AssetCategoryChild.

    :param category_id:
    :type category_id: int
    :param category_name:
    :type category_name: str
    :param category_code:
    :type category_code: str
    :param category_marker:
    :type category_marker:
     ~smartdiagnostics_sdk.models.AssetCategoryMarkerChild
    """

    _attribute_map = {
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'category_name': {'key': 'CategoryName', 'type': 'str'},
        'category_code': {'key': 'CategoryCode', 'type': 'str'},
        'category_marker': {'key': 'CategoryMarker', 'type': 'AssetCategoryMarkerChild'},
    }

    def __init__(self, **kwargs):
        super(AssetCategoryChild, self).__init__(**kwargs)
        self.category_id = kwargs.get('category_id', None)
        self.category_name = kwargs.get('category_name', None)
        self.category_code = kwargs.get('category_code', None)
        self.category_marker = kwargs.get('category_marker', None)
