# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallModifyUsersRequest(Model):
    """InstallModifyUsersRequest.

    :param user_ids:
    :type user_ids: list[str]
    """

    _attribute_map = {
        'user_ids': {'key': 'UserIds', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(InstallModifyUsersRequest, self).__init__(**kwargs)
        self.user_ids = kwargs.get('user_ids', None)
