# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetTypeChild(Model):
    """AssetTypeChild.

    :param type_id:
    :type type_id: int
    :param type_name:
    :type type_name: str
    :param type_code:
    :type type_code: str
    """

    _attribute_map = {
        'type_id': {'key': 'TypeId', 'type': 'int'},
        'type_name': {'key': 'TypeName', 'type': 'str'},
        'type_code': {'key': 'TypeCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AssetTypeChild, self).__init__(**kwargs)
        self.type_id = kwargs.get('type_id', None)
        self.type_name = kwargs.get('type_name', None)
        self.type_code = kwargs.get('type_code', None)
