# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LocationSettingsChild(Model):
    """LocationSettingsChild.

    :param max_transport_interval:
    :type max_transport_interval: int
    :param max_vibration_update_interval:
    :type max_vibration_update_interval: int
    :param max_oil_quality_update_interval:
    :type max_oil_quality_update_interval: int
    :param opc_enabled:
    :type opc_enabled: bool
    :param assign_filters_to_account:
    :type assign_filters_to_account: bool
    :param external_notification_type: Possible values include: 'Disabled',
     'Automatic', 'Manual'
    :type external_notification_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'max_transport_interval': {'key': 'MaxTransportInterval', 'type': 'int'},
        'max_vibration_update_interval': {'key': 'MaxVibrationUpdateInterval', 'type': 'int'},
        'max_oil_quality_update_interval': {'key': 'MaxOilQualityUpdateInterval', 'type': 'int'},
        'opc_enabled': {'key': 'OpcEnabled', 'type': 'bool'},
        'assign_filters_to_account': {'key': 'AssignFiltersToAccount', 'type': 'bool'},
        'external_notification_type': {'key': 'ExternalNotificationType', 'type': 'str'},
    }

    def __init__(self, *, max_transport_interval: int=None, max_vibration_update_interval: int=None, max_oil_quality_update_interval: int=None, opc_enabled: bool=None, assign_filters_to_account: bool=None, external_notification_type=None, **kwargs) -> None:
        super(LocationSettingsChild, self).__init__(**kwargs)
        self.max_transport_interval = max_transport_interval
        self.max_vibration_update_interval = max_vibration_update_interval
        self.max_oil_quality_update_interval = max_oil_quality_update_interval
        self.opc_enabled = opc_enabled
        self.assign_filters_to_account = assign_filters_to_account
        self.external_notification_type = external_notification_type
