# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpectrumChartSettingsCreateRequest(Model):
    """SpectrumChartSettingsCreateRequest.

    :param frequency_domain_settings:
    :type frequency_domain_settings:
     ~smartdiagnostics_sdk.models.FrequencyDomainSettingChild
    :param time_domain_settings:
    :type time_domain_settings: ~smartdiagnostics_sdk.models.MarkerChild
    """

    _attribute_map = {
        'frequency_domain_settings': {'key': 'FrequencyDomainSettings', 'type': 'FrequencyDomainSettingChild'},
        'time_domain_settings': {'key': 'TimeDomainSettings', 'type': 'MarkerChild'},
    }

    def __init__(self, **kwargs):
        super(SpectrumChartSettingsCreateRequest, self).__init__(**kwargs)
        self.frequency_domain_settings = kwargs.get('frequency_domain_settings', None)
        self.time_domain_settings = kwargs.get('time_domain_settings', None)
