# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HubPortChild(Model):
    """HubPortChild.

    :param hub_port_id:
    :type hub_port_id: long
    :param hub_port_number:
    :type hub_port_number: int
    :param hub_port_node:
    :type hub_port_node: ~smartdiagnostics_sdk.models.HubNodeChild
    """

    _attribute_map = {
        'hub_port_id': {'key': 'HubPortId', 'type': 'long'},
        'hub_port_number': {'key': 'HubPortNumber', 'type': 'int'},
        'hub_port_node': {'key': 'HubPortNode', 'type': 'HubNodeChild'},
    }

    def __init__(self, **kwargs):
        super(HubPortChild, self).__init__(**kwargs)
        self.hub_port_id = kwargs.get('hub_port_id', None)
        self.hub_port_number = kwargs.get('hub_port_number', None)
        self.hub_port_node = kwargs.get('hub_port_node', None)
