# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstallNodeResponse(Model):
    """InstallNodeResponse.

    :param node_id:
    :type node_id: long
    :param install_id:
    :type install_id: str
    :param node_serial_number:
    :type node_serial_number: str
    :param node_nickname:
    :type node_nickname: str
    :param install_status:
    :type install_status: ~smartdiagnostics_sdk.models.InstallNodeStatusChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    """

    _attribute_map = {
        'node_id': {'key': 'NodeId', 'type': 'long'},
        'install_id': {'key': 'InstallId', 'type': 'str'},
        'node_serial_number': {'key': 'NodeSerialNumber', 'type': 'str'},
        'node_nickname': {'key': 'NodeNickname', 'type': 'str'},
        'install_status': {'key': 'InstallStatus', 'type': 'InstallNodeStatusChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
    }

    def __init__(self, **kwargs):
        super(InstallNodeResponse, self).__init__(**kwargs)
        self.node_id = kwargs.get('node_id', None)
        self.install_id = kwargs.get('install_id', None)
        self.node_serial_number = kwargs.get('node_serial_number', None)
        self.node_nickname = kwargs.get('node_nickname', None)
        self.install_status = kwargs.get('install_status', None)
        self.location = kwargs.get('location', None)
