# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetChild(Model):
    """WidgetChild.

    All required parameters must be populated in order to send to Azure.

    :param widget_id: Required.
    :type widget_id: int
    :param widget_code: Possible values include: 'AssetMonitoring', 'Alerts',
     'TimeWarningAlarm', 'PerformanceOverall', 'PerformanceComparison',
     'PerformanceKpi', 'PerformanceScore', 'PerformanceTrend'
    :type widget_code: str or ~smartdiagnostics_sdk.models.enum
    :param widget_name: Required.
    :type widget_name: str
    :param widget_description:
    :type widget_description: str
    :param widget_type:
    :type widget_type: ~smartdiagnostics_sdk.models.WidgetTypeChild
    """

    _validation = {
        'widget_id': {'required': True},
        'widget_name': {'required': True},
    }

    _attribute_map = {
        'widget_id': {'key': 'WidgetId', 'type': 'int'},
        'widget_code': {'key': 'WidgetCode', 'type': 'str'},
        'widget_name': {'key': 'WidgetName', 'type': 'str'},
        'widget_description': {'key': 'WidgetDescription', 'type': 'str'},
        'widget_type': {'key': 'WidgetType', 'type': 'WidgetTypeChild'},
    }

    def __init__(self, *, widget_id: int, widget_name: str, widget_code=None, widget_description: str=None, widget_type=None, **kwargs) -> None:
        super(WidgetChild, self).__init__(**kwargs)
        self.widget_id = widget_id
        self.widget_code = widget_code
        self.widget_name = widget_name
        self.widget_description = widget_description
        self.widget_type = widget_type
