# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TreeItemAvailableAssetClassResponse(Model):
    """TreeItemAvailableAssetClassResponse.

    :param tree_item:
    :type tree_item: ~smartdiagnostics_sdk.models.TreeItemChild
    :param asset_class_code:
    :type asset_class_code: str
    :param asset_type:
    :type asset_type: ~smartdiagnostics_sdk.models.AssetTypeChild
    :param asset_category:
    :type asset_category: ~smartdiagnostics_sdk.models.AssetCategoryChild
    :param asset_size:
    :type asset_size: ~smartdiagnostics_sdk.models.AssetSizeChild
    """

    _attribute_map = {
        'tree_item': {'key': 'TreeItem', 'type': 'TreeItemChild'},
        'asset_class_code': {'key': 'AssetClassCode', 'type': 'str'},
        'asset_type': {'key': 'AssetType', 'type': 'AssetTypeChild'},
        'asset_category': {'key': 'AssetCategory', 'type': 'AssetCategoryChild'},
        'asset_size': {'key': 'AssetSize', 'type': 'AssetSizeChild'},
    }

    def __init__(self, *, tree_item=None, asset_class_code: str=None, asset_type=None, asset_category=None, asset_size=None, **kwargs) -> None:
        super(TreeItemAvailableAssetClassResponse, self).__init__(**kwargs)
        self.tree_item = tree_item
        self.asset_class_code = asset_class_code
        self.asset_type = asset_type
        self.asset_category = asset_category
        self.asset_size = asset_size
