# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareStatusResponse(Model):
    """HardwareStatusResponse.

    :param location_hardware_statuses:
    :type location_hardware_statuses:
     list[~smartdiagnostics_sdk.models.HardwareStatusChild]
    :param total_hardware_count:
    :type total_hardware_count: int
    :param total_unassigned_count:
    :type total_unassigned_count: int
    :param total_online_count:
    :type total_online_count: int
    :param total_offline_count:
    :type total_offline_count: int
    """

    _attribute_map = {
        'location_hardware_statuses': {'key': 'LocationHardwareStatuses', 'type': '[HardwareStatusChild]'},
        'total_hardware_count': {'key': 'TotalHardwareCount', 'type': 'int'},
        'total_unassigned_count': {'key': 'TotalUnassignedCount', 'type': 'int'},
        'total_online_count': {'key': 'TotalOnlineCount', 'type': 'int'},
        'total_offline_count': {'key': 'TotalOfflineCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(HardwareStatusResponse, self).__init__(**kwargs)
        self.location_hardware_statuses = kwargs.get('location_hardware_statuses', None)
        self.total_hardware_count = kwargs.get('total_hardware_count', None)
        self.total_unassigned_count = kwargs.get('total_unassigned_count', None)
        self.total_online_count = kwargs.get('total_online_count', None)
        self.total_offline_count = kwargs.get('total_offline_count', None)
