# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NodeStatusChild(Model):
    """NodeStatusChild.

    :param outstanding:
    :type outstanding: int
    :param deployed:
    :type deployed: int
    :param lock_out_tag_out:
    :type lock_out_tag_out: int
    :param spare_devices:
    :type spare_devices: int
    :param special_access_required:
    :type special_access_required: int
    """

    _attribute_map = {
        'outstanding': {'key': 'Outstanding', 'type': 'int'},
        'deployed': {'key': 'Deployed', 'type': 'int'},
        'lock_out_tag_out': {'key': 'LockOutTagOut', 'type': 'int'},
        'spare_devices': {'key': 'SpareDevices', 'type': 'int'},
        'special_access_required': {'key': 'SpecialAccessRequired', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(NodeStatusChild, self).__init__(**kwargs)
        self.outstanding = kwargs.get('outstanding', None)
        self.deployed = kwargs.get('deployed', None)
        self.lock_out_tag_out = kwargs.get('lock_out_tag_out', None)
        self.spare_devices = kwargs.get('spare_devices', None)
        self.special_access_required = kwargs.get('special_access_required', None)
