# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FrequencyDomainSettingChild(Model):
    """FrequencyDomainSettingChild.

    :param markers:
    :type markers: list[~smartdiagnostics_sdk.models.MarkerChild]
    :param custom_markers:
    :type custom_markers: list[~smartdiagnostics_sdk.models.CustomMarkerChild]
    :param selected_bearing:
    :type selected_bearing: str
    :param side_bands:
    :type side_bands: int
    :param side_band_frequency:
    :type side_band_frequency: int
    """

    _attribute_map = {
        'markers': {'key': 'Markers', 'type': '[MarkerChild]'},
        'custom_markers': {'key': 'CustomMarkers', 'type': '[CustomMarkerChild]'},
        'selected_bearing': {'key': 'SelectedBearing', 'type': 'str'},
        'side_bands': {'key': 'SideBands', 'type': 'int'},
        'side_band_frequency': {'key': 'SideBandFrequency', 'type': 'int'},
    }

    def __init__(self, *, markers=None, custom_markers=None, selected_bearing: str=None, side_bands: int=None, side_band_frequency: int=None, **kwargs) -> None:
        super(FrequencyDomainSettingChild, self).__init__(**kwargs)
        self.markers = markers
        self.custom_markers = custom_markers
        self.selected_bearing = selected_bearing
        self.side_bands = side_bands
        self.side_band_frequency = side_band_frequency
