# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BearingResponse(Model):
    """BearingResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name:
    :type name: str
    :param manufacturer:
    :type manufacturer: str
    :param roller_count:
    :type roller_count: long
    :param ftf:
    :type ftf: float
    :param bsf:
    :type bsf: float
    :param bpfo:
    :type bpfo: float
    :param bpfi:
    :type bpfi: float
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'manufacturer': {'key': 'Manufacturer', 'type': 'str'},
        'roller_count': {'key': 'RollerCount', 'type': 'long'},
        'ftf': {'key': 'Ftf', 'type': 'float'},
        'bsf': {'key': 'Bsf', 'type': 'float'},
        'bpfo': {'key': 'Bpfo', 'type': 'float'},
        'bpfi': {'key': 'Bpfi', 'type': 'float'},
    }

    def __init__(self, *, id: str, name: str=None, manufacturer: str=None, roller_count: int=None, ftf: float=None, bsf: float=None, bpfo: float=None, bpfi: float=None, **kwargs) -> None:
        super(BearingResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.manufacturer = manufacturer
        self.roller_count = roller_count
        self.ftf = ftf
        self.bsf = bsf
        self.bpfo = bpfo
        self.bpfi = bpfi
