# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardPermissionsUpdateRequest(Model):
    """DashboardPermissionsUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param is_sentry_managed: Required.
    :type is_sentry_managed: bool
    :param is_visible_to_customers: Required.
    :type is_visible_to_customers: bool
    """

    _validation = {
        'is_sentry_managed': {'required': True},
        'is_visible_to_customers': {'required': True},
    }

    _attribute_map = {
        'is_sentry_managed': {'key': 'IsSentryManaged', 'type': 'bool'},
        'is_visible_to_customers': {'key': 'IsVisibleToCustomers', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DashboardPermissionsUpdateRequest, self).__init__(**kwargs)
        self.is_sentry_managed = kwargs.get('is_sentry_managed', None)
        self.is_visible_to_customers = kwargs.get('is_visible_to_customers', None)
