# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyChild(Model):
    """HierarchyChild.

    :param hierarchy_id:
    :type hierarchy_id: str
    :param hierarchy_name:
    :type hierarchy_name: str
    :param hierarchy_abbreviation:
    :type hierarchy_abbreviation: str
    :param hierarchy_type:
    :type hierarchy_type: str
    """

    _attribute_map = {
        'hierarchy_id': {'key': 'HierarchyId', 'type': 'str'},
        'hierarchy_name': {'key': 'HierarchyName', 'type': 'str'},
        'hierarchy_abbreviation': {'key': 'HierarchyAbbreviation', 'type': 'str'},
        'hierarchy_type': {'key': 'HierarchyType', 'type': 'str'},
    }

    def __init__(self, *, hierarchy_id: str=None, hierarchy_name: str=None, hierarchy_abbreviation: str=None, hierarchy_type: str=None, **kwargs) -> None:
        super(HierarchyChild, self).__init__(**kwargs)
        self.hierarchy_id = hierarchy_id
        self.hierarchy_name = hierarchy_name
        self.hierarchy_abbreviation = hierarchy_abbreviation
        self.hierarchy_type = hierarchy_type
