# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorGroupUpdateRequest(Model):
    """IndicatorGroupUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param is_paused: Required.
    :type is_paused: bool
    """

    _validation = {
        'name': {'required': True, 'max_length': 100},
        'abbreviation': {'max_length': 5},
        'is_paused': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
    }

    def __init__(self, *, name: str, is_paused: bool, abbreviation: str=None, **kwargs) -> None:
        super(IndicatorGroupUpdateRequest, self).__init__(**kwargs)
        self.name = name
        self.abbreviation = abbreviation
        self.is_paused = is_paused
