# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetTemplateFilterChild(Model):
    """WidgetTemplateFilterChild.

    All required parameters must be populated in order to send to Azure.

    :param filter_data_field_code: Required.
    :type filter_data_field_code: str
    :param filter_data_field_name: Required.
    :type filter_data_field_name: str
    :param filter_operator: Required.
    :type filter_operator: str
    :param filter_value: Required.
    :type filter_value: str
    """

    _validation = {
        'filter_data_field_code': {'required': True},
        'filter_data_field_name': {'required': True},
        'filter_operator': {'required': True},
        'filter_value': {'required': True},
    }

    _attribute_map = {
        'filter_data_field_code': {'key': 'FilterDataFieldCode', 'type': 'str'},
        'filter_data_field_name': {'key': 'FilterDataFieldName', 'type': 'str'},
        'filter_operator': {'key': 'FilterOperator', 'type': 'str'},
        'filter_value': {'key': 'FilterValue', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WidgetTemplateFilterChild, self).__init__(**kwargs)
        self.filter_data_field_code = kwargs.get('filter_data_field_code', None)
        self.filter_data_field_name = kwargs.get('filter_data_field_name', None)
        self.filter_operator = kwargs.get('filter_operator', None)
        self.filter_value = kwargs.get('filter_value', None)
