# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareRevisionChild(Model):
    """HardwareRevisionChild.

    :param hardware_revision_id:
    :type hardware_revision_id: int
    :param hardware_revision_name:
    :type hardware_revision_name: str
    """

    _attribute_map = {
        'hardware_revision_id': {'key': 'HardwareRevisionId', 'type': 'int'},
        'hardware_revision_name': {'key': 'HardwareRevisionName', 'type': 'str'},
    }

    def __init__(self, *, hardware_revision_id: int=None, hardware_revision_name: str=None, **kwargs) -> None:
        super(HardwareRevisionChild, self).__init__(**kwargs)
        self.hardware_revision_id = hardware_revision_id
        self.hardware_revision_name = hardware_revision_name
