# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PagedResultsModelGroupAlertsResponse(Model):
    """PagedResultsModelGroupAlertsResponse.

    :param result: Contains a list of paged items
    :type result: list[~smartdiagnostics_sdk.models.GroupAlertsResponse]
    :param total: The total number of items returned from a query (not just
     those in the paged results list)
    :type total: int
    :param total_pages: The total number of pages of items that will be
     returned
    :type total_pages: int
    :param current_page: The current page of data that is being returned
    :type current_page: int
    :param page_size: The size of the page being returned
    :type page_size: int
    """

    _attribute_map = {
        'result': {'key': 'Result', 'type': '[GroupAlertsResponse]'},
        'total': {'key': 'Total', 'type': 'int'},
        'total_pages': {'key': 'TotalPages', 'type': 'int'},
        'current_page': {'key': 'CurrentPage', 'type': 'int'},
        'page_size': {'key': 'PageSize', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(PagedResultsModelGroupAlertsResponse, self).__init__(**kwargs)
        self.result = kwargs.get('result', None)
        self.total = kwargs.get('total', None)
        self.total_pages = kwargs.get('total_pages', None)
        self.current_page = kwargs.get('current_page', None)
        self.page_size = kwargs.get('page_size', None)
