# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReceiverChild(Model):
    """ReceiverChild.

    All required parameters must be populated in order to send to Azure.

    :param receiver_id: Required.
    :type receiver_id: long
    :param receiver_serial_number: Required.
    :type receiver_serial_number: str
    :param receiver_nickname:
    :type receiver_nickname: str
    :param receiver_firmware_version:
    :type receiver_firmware_version: str
    :param receiver_network_id:
    :type receiver_network_id: str
    :param receiver_rf_channel:
    :type receiver_rf_channel: int
    :param receiver_pending_rf_channel:
    :type receiver_pending_rf_channel: int
    """

    _validation = {
        'receiver_id': {'required': True},
        'receiver_serial_number': {'required': True},
    }

    _attribute_map = {
        'receiver_id': {'key': 'ReceiverId', 'type': 'long'},
        'receiver_serial_number': {'key': 'ReceiverSerialNumber', 'type': 'str'},
        'receiver_nickname': {'key': 'ReceiverNickname', 'type': 'str'},
        'receiver_firmware_version': {'key': 'ReceiverFirmwareVersion', 'type': 'str'},
        'receiver_network_id': {'key': 'ReceiverNetworkId', 'type': 'str'},
        'receiver_rf_channel': {'key': 'ReceiverRfChannel', 'type': 'int'},
        'receiver_pending_rf_channel': {'key': 'ReceiverPendingRfChannel', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ReceiverChild, self).__init__(**kwargs)
        self.receiver_id = kwargs.get('receiver_id', None)
        self.receiver_serial_number = kwargs.get('receiver_serial_number', None)
        self.receiver_nickname = kwargs.get('receiver_nickname', None)
        self.receiver_firmware_version = kwargs.get('receiver_firmware_version', None)
        self.receiver_network_id = kwargs.get('receiver_network_id', None)
        self.receiver_rf_channel = kwargs.get('receiver_rf_channel', None)
        self.receiver_pending_rf_channel = kwargs.get('receiver_pending_rf_channel', None)
