# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCategoryMarkerChild(Model):
    """AssetCategoryMarkerChild.

    :param category_marker_id:
    :type category_marker_id: int
    :param category_marker_name:
    :type category_marker_name: str
    :param category_marker_code:
    :type category_marker_code: str
    """

    _attribute_map = {
        'category_marker_id': {'key': 'CategoryMarkerId', 'type': 'int'},
        'category_marker_name': {'key': 'CategoryMarkerName', 'type': 'str'},
        'category_marker_code': {'key': 'CategoryMarkerCode', 'type': 'str'},
    }

    def __init__(self, *, category_marker_id: int=None, category_marker_name: str=None, category_marker_code: str=None, **kwargs) -> None:
        super(AssetCategoryMarkerChild, self).__init__(**kwargs)
        self.category_marker_id = category_marker_id
        self.category_marker_name = category_marker_name
        self.category_marker_code = category_marker_code
